@@ -88,9 +88,9 @@ class SatelliteML(DataSourceOutputML):
     ):
         """Create fake data"""
         if time_5 is None:
-            _, time_5, _ = make_random_time_vectors(
+            time_5 = make_random_time_vectors(
                 batch_size=batch_size, seq_length_5_minutes=seq_length_5, seq_length_30_minutes=0
-            )
+            )["time_5"]
 
         s = SatelliteML(
             batch_size=batch_size,
